pub struct LocalJson { /* private fields */ }
A MetadataGenerator that consults stored JSON files in the local filesystem.

Notes

Files must be stored at contract.json for contract-level metadata, and {token-id}.json for tokens, where token-id is the string representation of the decimal token id. e.g. 0.json, 384510.json, etc

This generator caches files in memory the first time they’re opened. If NFT metadata changes, the server will need to be re-booted to clear the cache. In addition, if you’re serving an egregious number of NFTs (or have large image-data properties), you may run out of memory as the cache grows

Implementations

Instantiate a LocalJson metadata generator. Creates directories up to the specified path

Errors
  • If the location exists and is not a directory
  • If the directory can’t be created