pub async fn contract_handler<T>(__arg0: State<Arc<T>>) -> Responsewhere
T: MetadataGenerator,Expand description
Simple handler that consults the metadata generator, and returns EITHER the contract metadata, or a 404
pub async fn contract_handler<T>(__arg0: State<Arc<T>>) -> Responsewhere
T: MetadataGenerator,Simple handler that consults the metadata generator, and returns EITHER the contract metadata, or a 404