Servers
Functions
- contract_
handler - Simple handler that consults the metadata generator, and returns EITHER the contract metadata, or a 404
- nft_
handler - Simple handler that consults the metadata generator, and returns EITHER the token metadata, or a 404
- return_
200 - Handler for healthcheck
- return_
404 - Fallback handler that returns a 404 with body
"unknown route" - serve_
generator - Serve an NFT generator at the specified socket address.
- serve_
generator_ with_ span - Serve an NFT generator at the specified socket address, running in a provided span.
- serve_
router - Serve an app with some shared state at the specified socket address.
Intended to allow full customization of the router. If a simple
no-customization JSON metadata server is required, instead use
serve_generator. - serve_
router_ with_ span - Serve an app with some shared state at the specified socket address instrumented with the provided span.