pub fn serve_generator<T>(t: T, socket: impl Into<SocketAddr>) -> JoinHandle<()>Expand description
Serve an NFT generator at the specified socket address.
Adds routes for /:token_id and /, as well as a fallback 404. This is a
simple, works-out-of-the-box JSON metadata server with no additional app or
routing customization. If you would like to add additional routes, consider
defining the axum Router and handlers separately, and passing your router
to serve_router